@@ -6,9 +6,9 @@ Type annotations for amp service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_amp.literals import ListWorkspacesPaginatorName
+    from mypy_boto3_amp.literals import AlertManagerDefinitionStatusCodeType
 
-    data: ListWorkspacesPaginatorName = "list_workspaces"
+    data: AlertManagerDefinitionStatusCodeType = "ACTIVE"
     ```
 """
 import sys
@@ -19,13 +19,34 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("ListWorkspacesPaginatorName", "WorkspaceStatusCodeType", "ServiceName")
+__all__ = (
+    "AlertManagerDefinitionStatusCodeType",
+    "ListRuleGroupsNamespacesPaginatorName",
+    "ListWorkspacesPaginatorName",
+    "RuleGroupsNamespaceStatusCodeType",
+    "WorkspaceActiveWaiterName",
+    "WorkspaceDeletedWaiterName",
+    "WorkspaceStatusCodeType",
+    "ServiceName",
+    "PaginatorName",
+    "WaiterName",
+)
 
 
+AlertManagerDefinitionStatusCodeType = Literal[
+    "ACTIVE", "CREATING", "CREATION_FAILED", "DELETING", "UPDATE_FAILED", "UPDATING"
+]
+ListRuleGroupsNamespacesPaginatorName = Literal["list_rule_groups_namespaces"]
 ListWorkspacesPaginatorName = Literal["list_workspaces"]
+RuleGroupsNamespaceStatusCodeType = Literal[
+    "ACTIVE", "CREATING", "CREATION_FAILED", "DELETING", "UPDATE_FAILED", "UPDATING"
+]
+WorkspaceActiveWaiterName = Literal["workspace_active"]
+WorkspaceDeletedWaiterName = Literal["workspace_deleted"]
 WorkspaceStatusCodeType = Literal["ACTIVE", "CREATING", "CREATION_FAILED", "DELETING", "UPDATING"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -58,6 +79,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
@@ -136,6 +158,7 @@ ServiceName = Literal[
     "glacier",
     "globalaccelerator",
     "glue",
+    "grafana",
     "greengrass",
     "greengrassv2",
     "groundstation",
@@ -294,10 +317,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -305,3 +330,5 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal["list_rule_groups_namespaces", "list_workspaces"]
+WaiterName = Literal["workspace_active", "workspace_deleted"]
